==> panel-0.14.3.tar.gz: panel-0.14.3/doc/getting_started/index.md <==
# Getting Started

Welcome to Panel!

The getting started guide will get you set up with Panel and provide a basic overview of the features and strengths of Panel. The [announcement blog](https://blog.pyviz.org/panel_announcement.html) is another great resource to learn about the features of Panel and get an idea of what it can do.

---

::::{grid} 1 2 2 3
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`plug;2.5em;sd-mr-1` Installation
:link: installation
:link-type: doc

Walks you through setting up your Python environment, installing Panel into it and how to configure your editor, IDE or notebook environment appropriately.

+++
[Learn more »](installation.rst)
:::

:::{grid-item-card} {octicon}`tools;2.5em;sd-mr-1` Build an app
:link: build_app
:link-type: doc

Before we dig into some of the core concepts behind Panel this guide gives you a quick tour taking you through the process of loading some data, displaying it and then building an application around it with some of the rich features that Panel supports.

+++
[Learn more »](build_app)
:::


:::{grid-item-card} {octicon}`rocket;2.5em;sd-mr-1` Core Concepts
:link: core_concepts
:link-type: doc

Introduces you to some of the core concepts behind Panel, how to develop Panel applications effectively both in your IDE and in the notebook and some of the core features that make Panel such a powerful library.

+++
[Learn more »](core_concepts)
:::

::::


```{toctree}
:titlesonly:
:hidden:
:maxdepth: 2

installation
build_app
core_concepts
```

==> panel-1.1.0rc1.tar.gz: panel-1.1.0rc1/doc/getting_started/index.md <==
# Getting Started

Welcome to Panel!

The getting started guide will get you set up with Panel and provide a basic overview of the features and strengths of Panel. The [announcement blog](https://blog.pyviz.org/panel_announcement.html) is another great resource to learn about the features of Panel and get an idea of what it can do.

---

::::{grid} 1 2 2 3
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`plug;2.5em;sd-mr-1` Installation
:link: installation
:link-type: doc

Walks you through setting up your Python environment, installing Panel into it and how to configure your editor, IDE or notebook environment appropriately.

+++
[Learn more »](installation)
:::

:::{grid-item-card} {octicon}`tools;2.5em;sd-mr-1` Build an app
:link: build_app
:link-type: doc

Before we dig into some of the core concepts behind Panel this guide gives you a quick tour taking you through the process of loading some data, displaying it and then building an application around it with some of the rich features that Panel supports.

+++
[Learn more »](build_app)
:::

:::{grid-item-card} {octicon}`rocket;2.5em;sd-mr-1` Core Concepts
:link: core_concepts
:link-type: doc

Introduces you to some of the core concepts behind Panel, how to develop Panel applications effectively both in your IDE and in the notebook and some of the core features that make Panel such a powerful library.

+++
[Learn more »](core_concepts)
:::

::::

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 2

installation
build_app
core_concepts
```
